@@ -1,14 +1,36 @@
 from functools import reduce
+from hestia_earth.validation.validators.shared import value_difference
 from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
-from hestia_earth.utils.tools import non_empty_list, safe_parse_float, flatten
+from hestia_earth.utils.tools import list_sum, non_empty_list, safe_parse_float, flatten
 
-from hestia_earth.validation.utils import _filter_list_errors, _value_range_error, _value_average
+from hestia_earth.validation.utils import _filter_list_errors, _value_range_error, _value_average, _node_year
+from hestia_earth.validation.gee import fetch_data
+from .shared import need_validate_coordinates
 
 
 SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
 
 
+def _rainfallAnnual(site: dict, measurement: dict):
+    year = _node_year(measurement)
+    value = fetch_data(collection='ECMWF/ERA5/MONTHLY',
+                       ee_type='raster_by_period',
+                       band_name='total_precipitation',
+                       reducer='sum',
+                       reducer_regions='mean',
+                       year=str(year),
+                       latitude=site.get('latitude'),
+                       longitude=site.get('longitude')
+                       ).get('mean', None) if need_validate_coordinates(site) and year else None
+    return value * 1000 if value else None
+
+
+MEASUREMENTS_MODELS = {
+    'rainfallAnnual': _rainfallAnnual
+}
+
+
 def _group_measurement_key(measurement: dict):
     keys = non_empty_list([
         str(measurement.get('depthUpper', '')),
@@ -160,3 +182,26 @@ def validate_require_startDate_endDate(measurements: list):
         ]
 
     return _filter_list_errors(flatten(map(validate, enumerate(measurements))))
+
+
+def validate_with_models(site: dict, list_key: str):
+    def validate(values: tuple):
+        index, blank_node = values
+        term_id = blank_node.get('term', {}).get('@id')
+        value = blank_node.get('value', [0])
+        value = list_sum(value, value)
+        expected_value = MEASUREMENTS_MODELS[term_id](site, blank_node) if term_id in MEASUREMENTS_MODELS else value
+        delta = value_difference(value, expected_value)
+        return expected_value is None or delta < 0.25 or {
+            'level': 'warning',
+            'dataPath': f".{list_key}[{index}].value",
+            'message': 'the measurement provided might be in error',
+            'params': {
+                'term': blank_node.get('term', {}),
+                'current': value,
+                'expected': expected_value,
+                'delta': delta * 100
+            }
+        }
+
+    return _filter_list_errors(flatten(map(validate, enumerate(site.get(list_key, [])))))
