@@ -3,7 +3,7 @@ import json
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.measurement import (
     validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
-    validate_require_startDate_endDate
+    validate_require_startDate_endDate, validate_with_models
 )
 
 
@@ -163,3 +163,32 @@ def test_validate_require_startDate_endDate_invalid():
         'dataPath': '.measurements[0].endDate',
         'message': 'is required'
     }]
+
+
+def test_validate_with_models_valid():
+    # no measurements should be valid
+    assert validate_with_models({}, 'measurements') is True
+
+    with open(f"{fixtures_path}/measurement/models/valid.json") as f:
+        data = json.load(f)
+    assert validate_with_models(data, 'measurements') is True
+
+
+def test_validate_with_models_invalid():
+    with open(f"{fixtures_path}/measurement/models/warning.json") as f:
+        data = json.load(f)
+    assert validate_with_models(data, 'measurements') == {
+        'level': 'warning',
+        'dataPath': '.measurements[0].value',
+        'message': 'the measurement provided might be in error',
+        'params': {
+            'current': 500,
+            'expected': 846.5314116328955,
+            'delta': 40.94,
+            'term': {
+                '@id': 'rainfallAnnual',
+                '@type': 'Term',
+                'name': 'Rainfall annual'
+            }
+        }
+    }
